# appiumfw
This is a python framework that customize the folder structure similar with Katalon's POM

# Run with shortcut
- Open file test_suite.yml or test_case.py
- Press `ctrl + F5`

# Run with command
- Open terminal
- Run: `python .\main.py tests\suites\login_suite.yml`